# zsh-tool Plugin

Use `mcp__zsh-tool__zsh` for zsh command execution with NEVERHANG protection and A.L.A.N. learning.

Prefer this over Bash when zsh-specific features are needed or when you want temporal learning about command patterns.